@@ -85,15 +85,13 @@ def make_instert_string(object, table):
 
     fileds = ""
     values = ""
-    #var= ""
 
     for name, value in object.items():
         if type(value) == str:
             value = value.replace("'", "''")
-            #print(value)
         fileds = fileds + name + ", "
 
-        if type(value) == dict:
+        if type(value) is dict:
             if value == {} or value == "":
                 values = values + "'{}', "
 
@@ -103,20 +101,22 @@ def make_instert_string(object, table):
                 value = json.loads(string)
                 values = values + "'" + json.dumps(value) + "', "
 
-        elif type(value) == bool:
+        elif type(value) is list and value == [] or type(value[0]) is str:
+            value = json.dumps(value).replace('"', "'")
+            values = values + " ARRAY" + value + "::text[], "
+
+        elif type(value) is bool:
 
             values = values + str(value) + ", "
 
         else:
             values = values + "'" + value + "', "
 
-
     insert_string = (
             "INSERT INTO " + table + " (" + (fileds[:-2])
             + ") VALUES (" + values[:-2] + ")")
 
     insert_string = insert_string.replace("'", "\'")
-
     print("INSERT STRING: " + insert_string)
 
     return insert_string
@@ -155,7 +155,6 @@ def make_update_string(object, table, key, key_value):
     )
 
     update_string = update_string.replace("'", "\'")
-
     print("UPDATE STRING: " + update_string)
 
     return update_string
\ No newline at end of file
